/*******************************************************************************
* File Name: Comp_Reference_PM.c  
* Version 1.70
*
*  Description:
*     This file provides the power management source code to API for the
*     VDAC8.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Comp_Reference.h"

static Comp_Reference_backupStruct Comp_Reference_backup;


/*******************************************************************************
* Function Name: Comp_Reference_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void Comp_Reference_SaveConfig(void)
{
    Comp_Reference_backup.data_value = Comp_Reference_Data;
}


/*******************************************************************************
* Function Name: Comp_Reference_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void Comp_Reference_RestoreConfig(void)
{
    Comp_Reference_Data = Comp_Reference_backup.data_value;
}


/*******************************************************************************
* Function Name: Comp_Reference_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Comp_Reference_backup.enableState:  Is modified depending on the enable 
* state  of the block before entering sleep mode.
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void Comp_Reference_Sleep(void)
{
    /* Save VDAC8's enable state */    
    if(Comp_Reference_ACT_PWR_EN == (Comp_Reference_PWRMGR & Comp_Reference_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Comp_Reference_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Comp_Reference_backup.enableState = 0u;
    }
    
    Comp_Reference_Stop();
    Comp_Reference_SaveConfig();
}


/*******************************************************************************
* Function Name: Comp_Reference_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Comp_Reference_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void Comp_Reference_Wakeup(void) 
{
    Comp_Reference_RestoreConfig();
    
    if(Comp_Reference_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Comp_Reference_Enable();

        /* Restore the data register */
        Comp_Reference_SetValue(Comp_Reference_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
