/*******************************************************************************
* File Name: CyMHz_CLK.h
* Version 1.60
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_CyMHz_CLK_H)
#define CY_CLOCK_CyMHz_CLK_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void CyMHz_CLK_Start(void) ;
void CyMHz_CLK_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void CyMHz_CLK_StopBlock(void) ;
#endif

void CyMHz_CLK_StandbyPower(uint8 state) ;
void CyMHz_CLK_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 CyMHz_CLK_GetDividerRegister(void) ;
void CyMHz_CLK_SetModeRegister(uint8 modeBitMask) ;
void CyMHz_CLK_ClearModeRegister(uint8 modeBitMask) ;
uint8 CyMHz_CLK_GetModeRegister(void) ;
void CyMHz_CLK_SetSourceRegister(uint8 clkSource) ;
uint8 CyMHz_CLK_GetSourceRegister(void) ;
#if defined(CyMHz_CLK__CFG3)
void CyMHz_CLK_SetPhaseRegister(uint8 clkPhase) ;
uint8 CyMHz_CLK_GetPhaseRegister(void) ;
#endif

#define CyMHz_CLK_Enable()                       CyMHz_CLK_Start()
#define CyMHz_CLK_Disable()                      CyMHz_CLK_Stop()
#define CyMHz_CLK_SetDivider(clkDivider)         CyMHz_CLK_SetDividerRegister(clkDivider, 1)
#define CyMHz_CLK_SetDividerValue(clkDivider)    CyMHz_CLK_SetDividerRegister((clkDivider) - 1, 1)
#define CyMHz_CLK_SetMode(clkMode)               CyMHz_CLK_SetModeRegister(clkMode)
#define CyMHz_CLK_SetSource(clkSource)           CyMHz_CLK_SetSourceRegister(clkSource)
#if defined(CyMHz_CLK__CFG3)
#define CyMHz_CLK_SetPhase(clkPhase)             CyMHz_CLK_SetPhaseRegister(clkPhase)
#define CyMHz_CLK_SetPhaseValue(clkPhase)        CyMHz_CLK_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CyMHz_CLK_CLKEN              (* (reg8 *) CyMHz_CLK__PM_ACT_CFG)
#define CyMHz_CLK_CLKEN_PTR          ((reg8 *) CyMHz_CLK__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CyMHz_CLK_CLKSTBY            (* (reg8 *) CyMHz_CLK__PM_STBY_CFG)
#define CyMHz_CLK_CLKSTBY_PTR        ((reg8 *) CyMHz_CLK__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CyMHz_CLK_DIV_LSB            (* (reg8 *) CyMHz_CLK__CFG0)
#define CyMHz_CLK_DIV_LSB_PTR        ((reg8 *) CyMHz_CLK__CFG0)
#define CyMHz_CLK_DIV_PTR            ((reg16 *) CyMHz_CLK__CFG0)

/* Clock MSB divider configuration register. */
#define CyMHz_CLK_DIV_MSB            (* (reg8 *) CyMHz_CLK__CFG1)
#define CyMHz_CLK_DIV_MSB_PTR        ((reg8 *) CyMHz_CLK__CFG1)

/* Mode and source configuration register */
#define CyMHz_CLK_MOD_SRC            (* (reg8 *) CyMHz_CLK__CFG2)
#define CyMHz_CLK_MOD_SRC_PTR        ((reg8 *) CyMHz_CLK__CFG2)

#if defined(CyMHz_CLK__CFG3)
/* Analog clock phase configuration register */
#define CyMHz_CLK_PHASE              (* (reg8 *) CyMHz_CLK__CFG3)
#define CyMHz_CLK_PHASE_PTR          ((reg8 *) CyMHz_CLK__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CyMHz_CLK_CLKEN_MASK         CyMHz_CLK__PM_ACT_MSK
#define CyMHz_CLK_CLKSTBY_MASK       CyMHz_CLK__PM_STBY_MSK

/* CFG2 field masks */
#define CyMHz_CLK_SRC_SEL_MSK        CyMHz_CLK__CFG2_SRC_SEL_MASK
#define CyMHz_CLK_MODE_MASK          (~(CyMHz_CLK_SRC_SEL_MSK))

#if defined(CyMHz_CLK__CFG3)
/* CFG3 phase mask */
#define CyMHz_CLK_PHASE_MASK         CyMHz_CLK__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_CyMHz_CLK_H */


/* [] END OF FILE */
