/*******************************************************************************
* File Name: Output_Opamp.c
* Version 1.70
*
* Description:
*  This file provides the source code to the API for OpAmp (Analog Buffer) 
*  Component.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Output_Opamp.h"
#include <CyLib.h>

uint8 Output_Opamp_initVar = 0u;

/* Check to see if required defines such as CY_PSOC3 and CY_PSOC5 are available */
/* They are defined starting with cy_boot v2.30 */
#ifndef CY_PSOC3
#error Component OpAmp_v1_70 requires cy_boot v2.30 or later
#endif


/*******************************************************************************   
* Function Name: Output_Opamp_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Output_Opamp_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
* Reentrant:
*  Yes
* 
*******************************************************************************/
void Output_Opamp_Init(void) 
{
    Output_Opamp_SetPower(Output_Opamp_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: Output_Opamp_Enable
********************************************************************************
*
* Summary:
*  Enables the OpAmp block operation
*
* Parameters:
*  void
*
* Return:
*  void
*
* Reentrant:
*  Yes
* 
*******************************************************************************/
void Output_Opamp_Enable(void) 
{
    /* Enable negative charge pumps in ANIF */
    Output_Opamp_PUMP_CR1_REG  |= (Output_Opamp_PUMP_CR1_CLKSEL | Output_Opamp_PUMP_CR1_FORCE);
    
    /* Enable power to buffer in active mode */
    Output_Opamp_PM_ACT_CFG_REG |= Output_Opamp_ACT_PWR_EN;
    
    /* Enable power to buffer in alternative active mode */
    Output_Opamp_PM_STBY_CFG_REG |= Output_Opamp_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name:   Output_Opamp_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters:
*  void
*
* Return:  
*  void
*
* Global variables:
*  Output_Opamp_initVar:  Used to check the initial configuration, modified 
*  when this function is called for the first time.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Output_Opamp_Start(void) 
{
    if(Output_Opamp_initVar == 0u)
    {
        Output_Opamp_initVar = 1u;
        Output_Opamp_Init();
    }
    
    Output_Opamp_Enable();
}


/*******************************************************************************
* Function Name: Output_Opamp_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*  void
*
* Return:  
*  void
*
* Reentrant: 
*  Yes
*
*******************************************************************************/
void Output_Opamp_Stop(void) 
{
    /* Disable negative charge pumps for ANIF only if the one ABuf is turned ON */
    if(Output_Opamp_PM_ACT_CFG_REG == Output_Opamp_ACT_PWR_EN)
    {
        Output_Opamp_PUMP_CR1_REG &= ~(Output_Opamp_PUMP_CR1_CLKSEL | Output_Opamp_PUMP_CR1_FORCE);
    }
    
    /* Disable power to buffer in active mode template */
    Output_Opamp_PM_ACT_CFG_REG &= ~Output_Opamp_ACT_PWR_EN;

    /* Disable power to buffer in alternative active mode template */
    Output_Opamp_PM_STBY_CFG_REG &= ~Output_Opamp_STBY_PWR_EN;
}


/*******************************************************************************
* Funciton Name:   Output_Opamp_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*  power:  PSoC3: Sets power level between low (1) and high power (3).
*          PSoC5: Sets power level High (0)
*
* Return:  
*  void
*
* Reentrant:
*  Yes
*
**********************************************************************************/
void Output_Opamp_SetPower(uint8 power) 
{
    /* Only High power can be used in PSoC5 */
    #if CY_PSOC5
        CYASSERT(power == Output_Opamp_HIGHPOWER);
    #endif
    
    Output_Opamp_CR_REG = ((Output_Opamp_CR_REG & ~Output_Opamp_PWR_MASK) | 
                               ( power & Output_Opamp_PWR_MASK));   /* Set device power */
}


/* [] END OF FILE */
