/*******************************************************************************
* File Name: Output_Opamp.h  
* Version 1.70
*
* Description:
*  This file contains the function prototypes and constants used in
*  the OpAmp (Analog Buffer) Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_OPAMP_Output_Opamp_H) 
#define CY_OPAMP_Output_Opamp_H 

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
*   Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct _Output_Opamp_backupStruct
{
    uint8   enableState;
}   Output_Opamp_BACKUP_STRUCT;


/**************************************
*        Function Prototypes 
**************************************/

void Output_Opamp_Start(void);
void Output_Opamp_Stop(void) ;
void Output_Opamp_SetPower(uint8 power) ;
void Output_Opamp_Sleep(void);
void Output_Opamp_Wakeup(void) ;
void Output_Opamp_SaveConfig(void);
void Output_Opamp_RestoreConfig(void);
void Output_Opamp_Init(void) ;
void Output_Opamp_Enable(void) ;


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetPower() function */
#if (CY_PSOC3_ES3 || CY_PSOC5_ES2)
    #define Output_Opamp_LPOCPOWER (0x00u)
    #define Output_Opamp_LOWPOWER  (0x01u)
    #define Output_Opamp_MEDPOWER  (0x02u)
    #define Output_Opamp_HIGHPOWER (0x03u)
#else
    #define Output_Opamp_LOWPOWER  (0x01u)
    #define Output_Opamp_MEDPOWER  (0x02u)
    #define Output_Opamp_HIGHPOWER (0x00u)
#endif

/**************************************
*           Parameter Defaults        
**************************************/
#if (CY_PSOC3_ES3 || CY_PSOC5_ES2)
    #define Output_Opamp_DEFAULT_POWER    (2u)
#endif

#if (CY_PSOC3_ES2 || CY_PSOC5_ES1)
    #if (2u == 0)
        #error "Low Power Over Compensated Mode is not supported on ES2 silicon. Please select another default power setting"
    #elif (2u == 3)
        #define Output_Opamp_DEFAULT_POWER (0u)
    #else
        #define Output_Opamp_DEFAULT_POWER (2u)
    #endif
#endif

#define Output_Opamp_DEFAULT_MODE     (1u)


/**************************************
*             Registers        
**************************************/

#define Output_Opamp_CR_REG        (* (reg8 *) Output_Opamp_ABuf__CR)
#define Output_Opamp_CR_PTR        (  (reg8 *) Output_Opamp_ABuf__CR)

#define Output_Opamp_MX_REG        (* (reg8 *) Output_Opamp_ABuf__MX)
#define Output_Opamp_MX_PTR        (  (reg8 *) Output_Opamp_ABuf__MX)

#define Output_Opamp_SW_REG        (* (reg8 *) Output_Opamp_ABuf__SW)
#define Output_Opamp_SW_PTR        (  (reg8 *) Output_Opamp_ABuf__SW)

/* Active mode power manager register */
#define Output_Opamp_PM_ACT_CFG_REG    (* (reg8 *) Output_Opamp_ABuf__PM_ACT_CFG)
#define Output_Opamp_PM_ACT_CFG_PTR    (  (reg8 *) Output_Opamp_ABuf__PM_ACT_CFG)

/* Alternative mode power manager register */
#define Output_Opamp_PM_STBY_CFG_REG    (* (reg8 *) Output_Opamp_ABuf__PM_STBY_CFG)
#define Output_Opamp_PM_STBY_CFG_PTR    (  (reg8 *) Output_Opamp_ABuf__PM_STBY_CFG)

/* ANIF.PUMP.CR1 Pump Configuration Register 1 */
#define Output_Opamp_PUMP_CR1_REG  (* (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)
#define Output_Opamp_PUMP_CR1_PTR  (  (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)

/* Trim register defines */
#define Output_Opamp_TRO_REG       (* (reg8 *) Output_Opamp_ABuf__TR0)
#define Output_Opamp_TRO_PTR       (  (reg8 *) Output_Opamp_ABuf__TR0)

#define Output_Opamp_TR1_REG       (* (reg8 *) Output_Opamp_ABuf__TR1)
#define Output_Opamp_TR1_PTR       (  (reg8 *) Output_Opamp_ABuf__TR1)

/* PM_ACT_CFG (Active Power Mode CFG Register) mask */ 
#define Output_Opamp_ACT_PWR_EN   Output_Opamp_ABuf__PM_ACT_MSK 

/* PM_STBY_CFG (Alternative Active Power Mode CFG Register) mask */ 
#define Output_Opamp_STBY_PWR_EN   Output_Opamp_ABuf__PM_STBY_MSK 


/**************************************
*       Register Constants        
**************************************/

/* CX Analog Buffer Input Selection Register */

/* Power mode defines */
#define Output_Opamp_PWR_MASK           (0x03u)
#if (CY_PSOC3_ES3 || CY_PSOC5_ES2)
    #define Output_Opamp_PWR_LPOC        (0x00u)
    #define Output_Opamp_PWR_LOW         (0x01u)
    #define Output_Opamp_PWR_MEDIUM      (0x02u)
    #define Output_Opamp_PWR_HIGH        (0x03u)
#else
    #define Output_Opamp_PWR_LOW         (0x01u)
    #define Output_Opamp_PWR_MEDIUM      (0x02u)
    #define Output_Opamp_PWR_HIGH        (0x00u)
#endif

/* MX Analog Buffer Input Selection Register */

/* Bit Field  MX_VN */
#define Output_Opamp_MX_VN_MASK       (0x30u)
#define Output_Opamp_MX_VN_NC         (0x00u)
#define Output_Opamp_MX_VN_AG4        (0x10u)
#define Output_Opamp_MX_VN_AG6        (0x20u)

/* Bit Field  MX_VP */
#define Output_Opamp_MX_VP_MASK       (0x0Fu)
#define Output_Opamp_MX_VP_NC         (0x00u)
#define Output_Opamp_MX_VP_VREF       (0x09u)
#define Output_Opamp_MX_VP_AG4        (0x01u)
#define Output_Opamp_MX_VP_AG5        (0x02u)
#define Output_Opamp_MX_VP_AG6        (0x03u)
#define Output_Opamp_MX_VP_AG7        (0x04u)
#define Output_Opamp_MX_VP_ABUS0      (0x05u)
#define Output_Opamp_MX_VP_ABUS1      (0x06u)
#define Output_Opamp_MX_VP_ABUS2      (0x07u)
#define Output_Opamp_MX_VP_ABUS3      (0x08u)

/* SW Analog Buffer Routing Switch Reg */

/* Bit Field  SW */
#define Output_Opamp_SW_MASK          (0x07u) 
#define Output_Opamp_SW_SWINP         (0x04u)  /* Enable positive input */
#define Output_Opamp_SW_SWINN         (0x02u)  /* Enable negative input */

/* Pump configuration register masks */
#define Output_Opamp_PUMP_CR1_CLKSEL  (0x40u)
#define Output_Opamp_PUMP_CR1_FORCE   (0x20u)
#define Output_Opamp_PUMP_CR1_AUTO    (0x10u)

#endif /* CY_OPAMP_Output_Opamp_H */



/* [] END OF FILE */
