/*******************************************************************************
* File Name: Output_drive_PM.c  
* Version 1.70
*
*  Description:
*     This file provides the power management source code to API for the
*     VDAC8.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Output_drive.h"

static Output_drive_backupStruct Output_drive_backup;


/*******************************************************************************
* Function Name: Output_drive_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void Output_drive_SaveConfig(void)
{
    Output_drive_backup.data_value = Output_drive_Data;
}


/*******************************************************************************
* Function Name: Output_drive_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void Output_drive_RestoreConfig(void)
{
    Output_drive_Data = Output_drive_backup.data_value;
}


/*******************************************************************************
* Function Name: Output_drive_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Output_drive_backup.enableState:  Is modified depending on the enable 
* state  of the block before entering sleep mode.
*
* Reenrancy: 
*  No
*
*******************************************************************************/
void Output_drive_Sleep(void)
{
    /* Save VDAC8's enable state */    
    if(Output_drive_ACT_PWR_EN == (Output_drive_PWRMGR & Output_drive_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Output_drive_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Output_drive_backup.enableState = 0u;
    }
    
    Output_drive_Stop();
    Output_drive_SaveConfig();
}


/*******************************************************************************
* Function Name: Output_drive_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Output_drive_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reenrancy: 
*  Yes
*
*******************************************************************************/
void Output_drive_Wakeup(void) 
{
    Output_drive_RestoreConfig();
    
    if(Output_drive_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Output_drive_Enable();

        /* Restore the data register */
        Output_drive_SetValue(Output_drive_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
