/*******************************************************************************
* File Name: SCP_Timeout.h  
* Version 2.10
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

#if !defined(CY_PWM_SCP_Timeout_H)
#define CY_PWM_SCP_Timeout_H


/***************************************
* Conditional Compilation Parameters
***************************************/
#define SCP_Timeout_Resolution 8u
#define SCP_Timeout_UsingFixedFunction 0u
#define SCP_Timeout_DeadBandMode 0u
#define SCP_Timeout_KillModeMinTime 0u
#define SCP_Timeout_KillMode 0u
#define SCP_Timeout_PWMMode 0u
#define SCP_Timeout_PWMModeIsCenterAligned 0u
#define SCP_Timeout_DeadBandUsed 0u
#define SCP_Timeout_DeadBand2_4 0u
#if !defined(SCP_Timeout_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define SCP_Timeout_UseStatus 1u
#else
    #define SCP_Timeout_UseStatus 0u
#endif
#if !defined(SCP_Timeout_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define SCP_Timeout_UseControl 1u
#else
    #define SCP_Timeout_UseControl 0u
#endif
#define SCP_Timeout_UseOneCompareMode 1u
#define SCP_Timeout_MinimumKillTime 1u
#define SCP_Timeout_EnableMode 0u

#define SCP_Timeout_CompareMode1SW 0u
#define SCP_Timeout_CompareMode2SW 0u

/* PSoC3 ES2 or early */
#define SCP_Timeout_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define SCP_Timeout_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))

/* PSoC3 ES3 or later */
#define SCP_Timeout_PSOC3_ES3   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                     (CYDEV_CHIP_REVISION_USED >= CYDEV_CHIP_REVISION_3A_ES3))

/* PSoC5 ES2 or later */
#define SCP_Timeout_PSOC5_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

/* Use Kill Mode Enumerated Types */
#define SCP_Timeout__B_PWM__DISABLED 0
#define SCP_Timeout__B_PWM__ASYNCHRONOUS 1
#define SCP_Timeout__B_PWM__SINGLECYCLE 2
#define SCP_Timeout__B_PWM__LATCHED 3
#define SCP_Timeout__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define SCP_Timeout__B_PWM__DBMDISABLED 0
#define SCP_Timeout__B_PWM__DBM_2_4_CLOCKS 1
#define SCP_Timeout__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define SCP_Timeout__B_PWM__ONE_OUTPUT 0
#define SCP_Timeout__B_PWM__TWO_OUTPUTS 1
#define SCP_Timeout__B_PWM__DUAL_EDGE 2
#define SCP_Timeout__B_PWM__CENTER_ALIGN 3
#define SCP_Timeout__B_PWM__DITHER 5
#define SCP_Timeout__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define SCP_Timeout__B_PWM__LESS_THAN 1
#define SCP_Timeout__B_PWM__LESS_THAN_OR_EQUAL 2
#define SCP_Timeout__B_PWM__GREATER_THAN 3
#define SCP_Timeout__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define SCP_Timeout__B_PWM__EQUAL 0
#define SCP_Timeout__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/

/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct SCP_Timeout_backupStruct
{
    
    uint8 PWMEnableState;
       
    #if(!SCP_Timeout_UsingFixedFunction)
        #if (SCP_Timeout_PSOC3_ES2 || SCP_Timeout_PSOC5_ES1)
            uint8 PWMUdb;               /* PWM Current Counter value  */
            uint8 PWMPeriod;            /* PWM Current Period value   */
            #if (SCP_Timeout_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            #if(SCP_Timeout_UseOneCompareMode)
                uint8 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint8 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint8 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif
            
            /* Backup for Deadband parameters */
            #if(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_256_CLOCKS || SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(SCP_Timeout_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
            
        #endif
        
        #if (SCP_Timeout_PSOC3_ES3 || SCP_Timeout_PSOC5_ES2)
            uint8 PWMUdb;               /* PWM Current Counter value  */
            #if(!SCP_Timeout_PWMModeIsCenterAligned)
                uint8 PWMPeriod;
            #endif
            #if (SCP_Timeout_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            
            /* Backup for Deadband parameters */
            #if(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_256_CLOCKS || SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(SCP_Timeout_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
        #endif
        
        
        /* Backup control register */
        #if(SCP_Timeout_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif
        
    #endif 
   
}SCP_Timeout_backupStruct;

/***************************************
*        Function Prototypes
 **************************************/
 
void    SCP_Timeout_Start(void);
void    SCP_Timeout_Stop(void) ;
#if (SCP_Timeout_UseStatus || SCP_Timeout_UsingFixedFunction)
    #define SCP_Timeout_SetInterruptMode(interruptMode) CY_SET_REG8(SCP_Timeout_STATUS_MASK_PTR, interruptMode)
    #define SCP_Timeout_ReadStatusRegister() CY_GET_REG8(SCP_Timeout_STATUS_PTR)
#endif
#define SCP_Timeout_GetInterruptSource() SCP_Timeout_ReadStatusRegister()
#if (SCP_Timeout_UseControl)
    #define SCP_Timeout_ReadControlRegister() CY_GET_REG8(SCP_Timeout_CONTROL_PTR) 
    #define SCP_Timeout_WriteControlRegister(control) CY_SET_REG8(SCP_Timeout_CONTROL_PTR, control)
#endif
#if (SCP_Timeout_UseOneCompareMode)
   #if (SCP_Timeout_CompareMode1SW)
       void    SCP_Timeout_SetCompareMode(uint8 comparemode) ;
   #endif
#else
    #if (SCP_Timeout_CompareMode1SW)
        void    SCP_Timeout_SetCompareMode1(uint8 comparemode) ;
    #endif
    #if (SCP_Timeout_CompareMode2SW)
        void    SCP_Timeout_SetCompareMode2(uint8 comparemode) ;
    #endif
#endif

#if (!SCP_Timeout_UsingFixedFunction)
    uint8   SCP_Timeout_ReadCounter(void) ;
    #define SCP_Timeout_ReadCapture() CY_GET_REG8(SCP_Timeout_CAPTURE_LSB_PTR)
    #if (SCP_Timeout_UseStatus)
        void SCP_Timeout_ClearFIFO(void) ;
    #endif
#endif

void    SCP_Timeout_WriteCounter(uint8 counter) ;
void    SCP_Timeout_WritePeriod(uint8 period) ;
#define SCP_Timeout_ReadPeriod() CY_GET_REG8(SCP_Timeout_PERIOD_LSB_PTR) 
#if (SCP_Timeout_UseOneCompareMode)
    void    SCP_Timeout_WriteCompare(uint8 compare) ;
    #define SCP_Timeout_ReadCompare() CY_GET_REG8(SCP_Timeout_COMPARE1_LSB_PTR) 
#else
    void    SCP_Timeout_WriteCompare1(uint8 compare) ;
    #define SCP_Timeout_ReadCompare1() CY_GET_REG8(SCP_Timeout_COMPARE1_LSB_PTR) 
    void    SCP_Timeout_WriteCompare2(uint8 compare) ;
    #define SCP_Timeout_ReadCompare2() CY_GET_REG8(SCP_Timeout_COMPARE2_LSB_PTR) 
#endif


#if (SCP_Timeout_DeadBandUsed)
    void    SCP_Timeout_WriteDeadTime(uint8 deadtime) ;
    uint8   SCP_Timeout_ReadDeadTime(void) ;
#endif

#if ( SCP_Timeout_KillModeMinTime)
    #define SCP_Timeout_WriteKillTime(killtime) CY_SET_REG8(SCP_Timeout_KILLMODEMINTIME_PTR, killtime) 
    #define SCP_Timeout_ReadKillTime() CY_GET_REG8(SCP_Timeout_KILLMODEMINTIME_PTR) 
#endif

void SCP_Timeout_Init(void) ;
void SCP_Timeout_Enable(void) ;
void SCP_Timeout_Sleep(void);
void SCP_Timeout_Wakeup(void) ;
void SCP_Timeout_SaveConfig(void);
void SCP_Timeout_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define SCP_Timeout_INIT_PERIOD_VALUE        99u
#define SCP_Timeout_INIT_COMPARE_VALUE1      49u
#define SCP_Timeout_INIT_COMPARE_VALUE2      63u
#define SCP_Timeout_INIT_INTERRUPTS_MODE     ((0u << SCP_Timeout_STATUS_TC_INT_EN_MASK_SHIFT) | (0 << SCP_Timeout_STATUS_CMP2_INT_EN_MASK_SHIFT) | (0 << SCP_Timeout_STATUS_CMP1_INT_EN_MASK_SHIFT ) | (0 << SCP_Timeout_STATUS_KILL_INT_EN_MASK_SHIFT ))
#define SCP_Timeout_DEFAULT_COMPARE2_MODE    (1u << SCP_Timeout_CTRL_CMPMODE2_SHIFT)
#define SCP_Timeout_DEFAULT_COMPARE1_MODE    (3u << SCP_Timeout_CTRL_CMPMODE1_SHIFT)
#define SCP_Timeout_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (SCP_Timeout_UsingFixedFunction)
   #define SCP_Timeout_PERIOD_LSB          (*(reg16 *) SCP_Timeout_PWMHW__PER0)
   #define SCP_Timeout_PERIOD_LSB_PTR      ( (reg16 *) SCP_Timeout_PWMHW__PER0)
   #define SCP_Timeout_COMPARE1_LSB        (*(reg16 *) SCP_Timeout_PWMHW__CNT_CMP0)
   #define SCP_Timeout_COMPARE1_LSB_PTR    ( (reg16 *) SCP_Timeout_PWMHW__CNT_CMP0)
   #define SCP_Timeout_COMPARE2_LSB        0x00u
   #define SCP_Timeout_COMPARE2_LSB_PTR    0x00u
   #define SCP_Timeout_COUNTER_LSB         (*(reg16 *) SCP_Timeout_PWMHW__CNT_CMP0)
   #define SCP_Timeout_COUNTER_LSB_PTR     ( (reg16 *) SCP_Timeout_PWMHW__CNT_CMP0)
   #define SCP_Timeout_CAPTURE_LSB         (*(reg16 *) SCP_Timeout_PWMHW__CAP0)
   #define SCP_Timeout_CAPTURE_LSB_PTR     ( (reg16 *) SCP_Timeout_PWMHW__CAP0)
   #define SCP_Timeout_RT1                 (*(reg8 *)  SCP_Timeout_PWMHW__RT1)
   #define SCP_Timeout_RT1_PTR             ( (reg8 *)  SCP_Timeout_PWMHW__RT1)
      
#else
   #if(SCP_Timeout_PWMModeIsCenterAligned)
       #define SCP_Timeout_PERIOD_LSB      (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define SCP_Timeout_PERIOD_LSB_PTR   ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__D1_REG)
   #else
       #define SCP_Timeout_PERIOD_LSB      (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #define SCP_Timeout_PERIOD_LSB_PTR   ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__F0_REG)
   #endif
   #define SCP_Timeout_COMPARE1_LSB    (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__D0_REG)
   #define SCP_Timeout_COMPARE1_LSB_PTR ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__D0_REG)
   #define SCP_Timeout_COMPARE2_LSB    (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__D1_REG)
   #define SCP_Timeout_COMPARE2_LSB_PTR ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__D1_REG)
   #define SCP_Timeout_COUNTERCAP_LSB   *(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define SCP_Timeout_COUNTERCAP_LSB_PTR ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define SCP_Timeout_COUNTER_LSB     (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__A0_REG)
   #define SCP_Timeout_COUNTER_LSB_PTR  ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__A0_REG)
   #define SCP_Timeout_CAPTURE_LSB     (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__F1_REG)
   #define SCP_Timeout_CAPTURE_LSB_PTR  ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__F1_REG)
   #define SCP_Timeout_AUX_CONTROLDP0      (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define SCP_Timeout_AUX_CONTROLDP0_PTR  ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #if (SCP_Timeout_Resolution == 16)
       #define SCP_Timeout_AUX_CONTROLDP1    (*(reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define SCP_Timeout_AUX_CONTROLDP1_PTR  ((reg8 *) SCP_Timeout_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
   #endif
#endif
   
#if(SCP_Timeout_KillModeMinTime )
    #define SCP_Timeout_KILLMODEMINTIME      (*(reg8 *) SCP_Timeout_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define SCP_Timeout_KILLMODEMINTIME_PTR   ((reg8 *) SCP_Timeout_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif

#if(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_256_CLOCKS)
    #define SCP_Timeout_DEADBAND_COUNT        (*(reg8 *) SCP_Timeout_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define SCP_Timeout_DEADBAND_COUNT_PTR     ((reg8 *) SCP_Timeout_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define SCP_Timeout_DEADBAND_LSB_PTR       ((reg8 *) SCP_Timeout_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define SCP_Timeout_DEADBAND_LSB          (*(reg8 *) SCP_Timeout_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (SCP_Timeout_UsingFixedFunction)
        #define SCP_Timeout_DEADBAND_COUNT        (*(reg8 *) SCP_Timeout_PWMHW__CFG0) 
        #define SCP_Timeout_DEADBAND_COUNT_PTR     ((reg8 *) SCP_Timeout_PWMHW__CFG0)
        #define SCP_Timeout_DEADBAND_COUNT_MASK    (0x03u << SCP_Timeout_DEADBAND_COUNT_SHIFT) 
        #define SCP_Timeout_DEADBAND_COUNT_SHIFT   0x06u /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */ 
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define SCP_Timeout_DEADBAND_COUNT        (*(reg8 *) SCP_Timeout_PWMUDB_sDB3_SyncCtl_dbctrlreg__CONTROL_REG)
        #define SCP_Timeout_DEADBAND_COUNT_PTR     ((reg8 *) SCP_Timeout_PWMUDB_sDB3_SyncCtl_dbctrlreg__CONTROL_REG)
        #define SCP_Timeout_DEADBAND_COUNT_MASK    (0x03u << SCP_Timeout_DEADBAND_COUNT_SHIFT) 
        #define SCP_Timeout_DEADBAND_COUNT_SHIFT   0x00u /* As defined by the verilog implementation of the Control Register */
    #endif
#endif



#if (SCP_Timeout_UsingFixedFunction)
    #define SCP_Timeout_STATUS                (*(reg8 *) SCP_Timeout_PWMHW__SR0)
    #define SCP_Timeout_STATUS_PTR            ((reg8 *) SCP_Timeout_PWMHW__SR0)
    #define SCP_Timeout_STATUS_MASK           (*(reg8 *) SCP_Timeout_PWMHW__SR0)
    #define SCP_Timeout_STATUS_MASK_PTR       ((reg8 *) SCP_Timeout_PWMHW__SR0)
    #define SCP_Timeout_CONTROL               (*(reg8 *) SCP_Timeout_PWMHW__CFG0)
    #define SCP_Timeout_CONTROL_PTR           ((reg8 *) SCP_Timeout_PWMHW__CFG0)    
    #define SCP_Timeout_CONTROL2              (*(reg8 *) SCP_Timeout_PWMHW__CFG1)    
    #if(SCP_Timeout_PSOC3_ES3 || SCP_Timeout_PSOC5_ES2)
        #define SCP_Timeout_CONTROL3              (*(reg8 *) SCP_Timeout_PWMHW__CFG2)
    #endif
    #define SCP_Timeout_GLOBAL_ENABLE         (*(reg8 *) SCP_Timeout_PWMHW__PM_ACT_CFG)
    #define SCP_Timeout_GLOBAL_ENABLE_PTR       ( (reg8 *) SCP_Timeout_PWMHW__PM_ACT_CFG)
    #define SCP_Timeout_GLOBAL_STBY_ENABLE      (*(reg8 *) SCP_Timeout_PWMHW__PM_STBY_CFG)
    #define SCP_Timeout_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) SCP_Timeout_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/
    /* Fixed Function Block Chosen */
    #define SCP_Timeout_BLOCK_EN_MASK          SCP_Timeout_PWMHW__PM_ACT_MSK
    #define SCP_Timeout_BLOCK_STBY_EN_MASK     SCP_Timeout_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define SCP_Timeout_CTRL_ENABLE_SHIFT      0x00u
    
    #if(SCP_Timeout_PSOC3_ES2 || SCP_Timeout_PSOC5_ES1)
        #define SCP_Timeout_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif
    #if(SCP_Timeout_PSOC3_ES3 || SCP_Timeout_PSOC5_ES2)
        #define SCP_Timeout_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif
    
    #define SCP_Timeout_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define SCP_Timeout_CFG0_MODE              0x02u   /*  Set to compare mode */
    //#define SCP_Timeout_CFG0_ENABLE            0x01u   /* Enable the block to run */
    #define SCP_Timeout_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define SCP_Timeout_CTRL_ENABLE            (0x01u << SCP_Timeout_CTRL_ENABLE_SHIFT)
    #define SCP_Timeout_CTRL_RESET             (0x01u << SCP_Timeout_CTRL_RESET_SHIFT)
    #define SCP_Timeout_CTRL_CMPMODE2_MASK     (0x07u << SCP_Timeout_CTRL_CMPMODE2_SHIFT)
    #if(SCP_Timeout_PSOC3_ES2 || SCP_Timeout_PSOC5_ES1)
        #define SCP_Timeout_CTRL_CMPMODE1_MASK     (0x07u << SCP_Timeout_CTRL_CMPMODE1_SHIFT)
    #endif
    #if(SCP_Timeout_PSOC3_ES3 || SCP_Timeout_PSOC5_ES2)
        #define SCP_Timeout_CTRL_CMPMODE1_MASK     (0x07u << SCP_Timeout_CTRL_CMPMODE1_SHIFT)
    #endif
    
    /* Control2 Register Bit Masks */
    #define SCP_Timeout_CTRL2_IRQ_SEL_SHIFT    0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define SCP_Timeout_CTRL2_IRQ_SEL          (0x01u << SCP_Timeout_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define SCP_Timeout_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define SCP_Timeout_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define SCP_Timeout_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define SCP_Timeout_STATUS_TC_INT_EN_MASK_SHIFT            (SCP_Timeout_STATUS_TC_SHIFT - 4)
    #define SCP_Timeout_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define SCP_Timeout_STATUS_CMP1_INT_EN_MASK_SHIFT          (SCP_Timeout_STATUS_CMP1_SHIFT - 4)
    
    /* Status Register Bit Masks */
    #define SCP_Timeout_STATUS_TC              (0x01u << SCP_Timeout_STATUS_TC_SHIFT)
    #define SCP_Timeout_STATUS_CMP1            (0x01u << SCP_Timeout_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define SCP_Timeout_STATUS_TC_INT_EN_MASK              (SCP_Timeout_STATUS_TC >> 4)
    #define SCP_Timeout_STATUS_CMP1_INT_EN_MASK            (SCP_Timeout_STATUS_CMP1 >> 4)
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define SCP_Timeout_RT1_SHIFT              0x04u
    #define SCP_Timeout_RT1_MASK               (0x03u << SCP_Timeout_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define SCP_Timeout_SYNC                   (0x03u << SCP_Timeout_RT1_SHIFT)
    #define SCP_Timeout_SYNCDSI_SHIFT          0x00u
    #define SCP_Timeout_SYNCDSI_MASK           (0x0Fu << SCP_Timeout_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define SCP_Timeout_SYNCDSI_EN             (0x0Fu << SCP_Timeout_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define SCP_Timeout_STATUS                (*(reg8 *) SCP_Timeout_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define SCP_Timeout_STATUS_PTR            ((reg8 *) SCP_Timeout_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define SCP_Timeout_STATUS_MASK           (*(reg8 *) SCP_Timeout_PWMUDB_sSTSReg_rstSts_stsreg__MASK_REG)
    #define SCP_Timeout_STATUS_MASK_PTR       ((reg8 *) SCP_Timeout_PWMUDB_sSTSReg_rstSts_stsreg__MASK_REG)
    #define SCP_Timeout_STATUS_AUX_CTRL       (*(reg8 *) SCP_Timeout_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define SCP_Timeout_CONTROL               (*(reg8 *) SCP_Timeout_PWMUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    #define SCP_Timeout_CONTROL_PTR           ((reg8 *) SCP_Timeout_PWMUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/
    /* Control Register definitions */
    #define SCP_Timeout_CTRL_ENABLE_SHIFT      0x07u
    #define SCP_Timeout_CTRL_RESET_SHIFT       0x06u
    #define SCP_Timeout_CTRL_CMPMODE2_SHIFT    0x03u
    #define SCP_Timeout_CTRL_CMPMODE1_SHIFT    0x00u
    #define SCP_Timeout_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define SCP_Timeout_CTRL_ENABLE            (0x01u << SCP_Timeout_CTRL_ENABLE_SHIFT)
    #define SCP_Timeout_CTRL_RESET             (0x01u << SCP_Timeout_CTRL_RESET_SHIFT)
    #define SCP_Timeout_CTRL_CMPMODE2_MASK     (0x07u << SCP_Timeout_CTRL_CMPMODE2_SHIFT)
    #define SCP_Timeout_CTRL_CMPMODE1_MASK     (0x07u << SCP_Timeout_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define SCP_Timeout_STATUS_KILL_SHIFT          0x05u
    #define SCP_Timeout_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define SCP_Timeout_STATUS_FIFOFULL_SHIFT      0x03u  
    #define SCP_Timeout_STATUS_TC_SHIFT            0x02u
    #define SCP_Timeout_STATUS_CMP2_SHIFT          0x01u
    #define SCP_Timeout_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define SCP_Timeout_STATUS_KILL_INT_EN_MASK_SHIFT          SCP_Timeout_STATUS_KILL_SHIFT          
    #define SCP_Timeout_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    SCP_Timeout_STATUS_FIFONEMPTY_SHIFT    
    #define SCP_Timeout_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      SCP_Timeout_STATUS_FIFOFULL_SHIFT        
    #define SCP_Timeout_STATUS_TC_INT_EN_MASK_SHIFT            SCP_Timeout_STATUS_TC_SHIFT            
    #define SCP_Timeout_STATUS_CMP2_INT_EN_MASK_SHIFT          SCP_Timeout_STATUS_CMP2_SHIFT          
    #define SCP_Timeout_STATUS_CMP1_INT_EN_MASK_SHIFT          SCP_Timeout_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define SCP_Timeout_STATUS_KILL            (0x00u << SCP_Timeout_STATUS_KILL_SHIFT )
    #define SCP_Timeout_STATUS_FIFOFULL        (0x01u << SCP_Timeout_STATUS_FIFOFULL_SHIFT)
    #define SCP_Timeout_STATUS_FIFONEMPTY      (0x01u << SCP_Timeout_STATUS_FIFONEMPTY_SHIFT)
    #define SCP_Timeout_STATUS_TC              (0x01u << SCP_Timeout_STATUS_TC_SHIFT)
    #define SCP_Timeout_STATUS_CMP2            (0x01u << SCP_Timeout_STATUS_CMP2_SHIFT) 
    #define SCP_Timeout_STATUS_CMP1            (0x01u << SCP_Timeout_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define SCP_Timeout_STATUS_KILL_INT_EN_MASK            SCP_Timeout_STATUS_KILL
    #define SCP_Timeout_STATUS_FIFOFULL_INT_EN_MASK        SCP_Timeout_STATUS_FIFOFULL
    #define SCP_Timeout_STATUS_FIFONEMPTY_INT_EN_MASK      SCP_Timeout_STATUS_FIFONEMPTY
    #define SCP_Timeout_STATUS_TC_INT_EN_MASK              SCP_Timeout_STATUS_TC
    #define SCP_Timeout_STATUS_CMP2_INT_EN_MASK            SCP_Timeout_STATUS_CMP2
    #define SCP_Timeout_STATUS_CMP1_INT_EN_MASK            SCP_Timeout_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define SCP_Timeout_AUX_CTRL_FIFO0_CLR     0x01u
    #define SCP_Timeout_AUX_CTRL_FIFO1_CLR     0x02u
    #define SCP_Timeout_AUX_CTRL_FIFO0_LVL     0x04u
    #define SCP_Timeout_AUX_CTRL_FIFO1_LVL     0x08u
    #define SCP_Timeout_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* SCP_Timeout_UsingFixedFunction */

#endif  /* CY_PWM_SCP_Timeout_H */
