/*******************************************************************************
* File Name: SCP_Timeout_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "SCP_Timeout.h"

static SCP_Timeout_backupStruct SCP_Timeout_backup;


/*******************************************************************************
* Function Name: SCP_Timeout_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timeout_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SCP_Timeout_SaveConfig(void)
{
    
    #if(!SCP_Timeout_UsingFixedFunction)
        #if (SCP_Timeout_PSOC3_ES2 || SCP_Timeout_PSOC5_ES1)
            SCP_Timeout_backup.PWMUdb = SCP_Timeout_ReadCounter();
            SCP_Timeout_backup.PWMPeriod = SCP_Timeout_ReadPeriod();
            #if (SCP_Timeout_UseStatus)
                SCP_Timeout_backup.InterruptMaskValue = SCP_Timeout_STATUS_MASK;
            #endif
            
            #if(SCP_Timeout_UseOneCompareMode)
                SCP_Timeout_backup.PWMCompareValue = SCP_Timeout_ReadCompare();
            #else
                SCP_Timeout_backup.PWMCompareValue1 = SCP_Timeout_ReadCompare1();
                SCP_Timeout_backup.PWMCompareValue2 = SCP_Timeout_ReadCompare2();
            #endif
            
           #if(SCP_Timeout_DeadBandUsed)
                SCP_Timeout_backup.PWMdeadBandValue = SCP_Timeout_ReadDeadTime();
            #endif
          
            #if ( SCP_Timeout_KillModeMinTime)
                SCP_Timeout_backup.PWMKillCounterPeriod = SCP_Timeout_ReadKillTime();
            #endif
        #endif
        
        #if (SCP_Timeout_PSOC3_ES3 || SCP_Timeout_PSOC5_ES2)
            #if(!SCP_Timeout_PWMModeIsCenterAligned)
                SCP_Timeout_backup.PWMPeriod = SCP_Timeout_ReadPeriod();
            #endif
            SCP_Timeout_backup.PWMUdb = SCP_Timeout_ReadCounter();
            #if (SCP_Timeout_UseStatus)
                SCP_Timeout_backup.InterruptMaskValue = SCP_Timeout_STATUS_MASK;
            #endif
            
            #if(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_256_CLOCKS || SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_2_4_CLOCKS)
                SCP_Timeout_backup.PWMdeadBandValue = SCP_Timeout_ReadDeadTime();
            #endif
            
            #if(SCP_Timeout_KillModeMinTime)
                 SCP_Timeout_backup.PWMKillCounterPeriod = SCP_Timeout_ReadKillTime();
            #endif
        #endif
        
        #if(SCP_Timeout_UseControl)
            SCP_Timeout_backup.PWMControlRegister = SCP_Timeout_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: SCP_Timeout_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timeout_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void SCP_Timeout_RestoreConfig(void) 
{
        #if(!SCP_Timeout_UsingFixedFunction)
            #if (SCP_Timeout_PSOC3_ES2 || SCP_Timeout_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 SCP_Timeout_interruptState;
                /* Enter Critical Region*/
                SCP_Timeout_interruptState = CyEnterCriticalSection();
                #if (SCP_Timeout_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    SCP_Timeout_STATUS_AUX_CTRL |= SCP_Timeout_STATUS_ACTL_INT_EN_MASK;
                    
                    SCP_Timeout_STATUS_MASK = SCP_Timeout_backup.InterruptMaskValue;
                #endif
                
                #if (SCP_Timeout_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    SCP_Timeout_AUX_CONTROLDP0 |= (SCP_Timeout_AUX_CTRL_FIFO0_CLR);
                #else /* (SCP_Timeout_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    SCP_Timeout_AUX_CONTROLDP0 |= (SCP_Timeout_AUX_CTRL_FIFO0_CLR);
                    SCP_Timeout_AUX_CONTROLDP1 |= (SCP_Timeout_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(SCP_Timeout_interruptState);
                
                SCP_Timeout_WriteCounter(SCP_Timeout_backup.PWMUdb);
                SCP_Timeout_WritePeriod(SCP_Timeout_backup.PWMPeriod);
                
                #if(SCP_Timeout_UseOneCompareMode)
                    SCP_Timeout_WriteCompare(SCP_Timeout_backup.PWMCompareValue);
                #else
                    SCP_Timeout_WriteCompare1(SCP_Timeout_backup.PWMCompareValue1);
                    SCP_Timeout_WriteCompare2(SCP_Timeout_backup.PWMCompareValue2);
                #endif
                
               #if(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_256_CLOCKS || SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_2_4_CLOCKS)
                    SCP_Timeout_WriteDeadTime(SCP_Timeout_backup.PWMdeadBandValue);
                #endif
            
                #if ( SCP_Timeout_KillModeMinTime)
                    SCP_Timeout_WriteKillTime(SCP_Timeout_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (SCP_Timeout_PSOC3_ES3 || SCP_Timeout_PSOC5_ES2)
                #if(!SCP_Timeout_PWMModeIsCenterAligned)
                    SCP_Timeout_WritePeriod(SCP_Timeout_backup.PWMPeriod);
                #endif
                SCP_Timeout_WriteCounter(SCP_Timeout_backup.PWMUdb);
                #if (SCP_Timeout_UseStatus)
                    SCP_Timeout_STATUS_MASK = SCP_Timeout_backup.InterruptMaskValue;
                #endif
                
                #if(SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_256_CLOCKS || SCP_Timeout_DeadBandMode == SCP_Timeout__B_PWM__DBM_2_4_CLOCKS)
                    SCP_Timeout_WriteDeadTime(SCP_Timeout_backup.PWMdeadBandValue);
                #endif
                
                #if(SCP_Timeout_KillModeMinTime)
                    SCP_Timeout_WriteKillTime(SCP_Timeout_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(SCP_Timeout_UseControl)
                SCP_Timeout_WriteControlRegister(SCP_Timeout_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: SCP_Timeout_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timeout_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SCP_Timeout_Sleep(void)
{
    #if(SCP_Timeout_UseControl)
        if(SCP_Timeout_CTRL_ENABLE == (SCP_Timeout_CONTROL & SCP_Timeout_CTRL_ENABLE))
        {
            /*Component is enabled */
            SCP_Timeout_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            SCP_Timeout_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    SCP_Timeout_Stop();
    
    /* Save registers configuration */
    SCP_Timeout_SaveConfig();
}


/*******************************************************************************
* Function Name: SCP_Timeout_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timeout_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void SCP_Timeout_Wakeup(void) 
{
     /* Restore registers values */
    SCP_Timeout_RestoreConfig();
    
    if(SCP_Timeout_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        SCP_Timeout_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
