/*******************************************************************************
* File Name: SCP_Timer_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "SCP_Timer.h"

static SCP_Timer_backupStruct SCP_Timer_backup;


/*******************************************************************************
* Function Name: SCP_Timer_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timer_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SCP_Timer_SaveConfig(void)
{
    
    #if(!SCP_Timer_UsingFixedFunction)
        #if (SCP_Timer_PSOC3_ES2 || SCP_Timer_PSOC5_ES1)
            SCP_Timer_backup.PWMUdb = SCP_Timer_ReadCounter();
            SCP_Timer_backup.PWMPeriod = SCP_Timer_ReadPeriod();
            #if (SCP_Timer_UseStatus)
                SCP_Timer_backup.InterruptMaskValue = SCP_Timer_STATUS_MASK;
            #endif
            
            #if(SCP_Timer_UseOneCompareMode)
                SCP_Timer_backup.PWMCompareValue = SCP_Timer_ReadCompare();
            #else
                SCP_Timer_backup.PWMCompareValue1 = SCP_Timer_ReadCompare1();
                SCP_Timer_backup.PWMCompareValue2 = SCP_Timer_ReadCompare2();
            #endif
            
           #if(SCP_Timer_DeadBandUsed)
                SCP_Timer_backup.PWMdeadBandValue = SCP_Timer_ReadDeadTime();
            #endif
          
            #if ( SCP_Timer_KillModeMinTime)
                SCP_Timer_backup.PWMKillCounterPeriod = SCP_Timer_ReadKillTime();
            #endif
        #endif
        
        #if (SCP_Timer_PSOC3_ES3 || SCP_Timer_PSOC5_ES2)
            #if(!SCP_Timer_PWMModeIsCenterAligned)
                SCP_Timer_backup.PWMPeriod = SCP_Timer_ReadPeriod();
            #endif
            SCP_Timer_backup.PWMUdb = SCP_Timer_ReadCounter();
            #if (SCP_Timer_UseStatus)
                SCP_Timer_backup.InterruptMaskValue = SCP_Timer_STATUS_MASK;
            #endif
            
            #if(SCP_Timer_DeadBandMode == SCP_Timer__B_PWM__DBM_256_CLOCKS || SCP_Timer_DeadBandMode == SCP_Timer__B_PWM__DBM_2_4_CLOCKS)
                SCP_Timer_backup.PWMdeadBandValue = SCP_Timer_ReadDeadTime();
            #endif
            
            #if(SCP_Timer_KillModeMinTime)
                 SCP_Timer_backup.PWMKillCounterPeriod = SCP_Timer_ReadKillTime();
            #endif
        #endif
        
        #if(SCP_Timer_UseControl)
            SCP_Timer_backup.PWMControlRegister = SCP_Timer_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: SCP_Timer_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timer_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void SCP_Timer_RestoreConfig(void) 
{
        #if(!SCP_Timer_UsingFixedFunction)
            #if (SCP_Timer_PSOC3_ES2 || SCP_Timer_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 SCP_Timer_interruptState;
                /* Enter Critical Region*/
                SCP_Timer_interruptState = CyEnterCriticalSection();
                #if (SCP_Timer_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    SCP_Timer_STATUS_AUX_CTRL |= SCP_Timer_STATUS_ACTL_INT_EN_MASK;
                    
                    SCP_Timer_STATUS_MASK = SCP_Timer_backup.InterruptMaskValue;
                #endif
                
                #if (SCP_Timer_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    SCP_Timer_AUX_CONTROLDP0 |= (SCP_Timer_AUX_CTRL_FIFO0_CLR);
                #else /* (SCP_Timer_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    SCP_Timer_AUX_CONTROLDP0 |= (SCP_Timer_AUX_CTRL_FIFO0_CLR);
                    SCP_Timer_AUX_CONTROLDP1 |= (SCP_Timer_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(SCP_Timer_interruptState);
                
                SCP_Timer_WriteCounter(SCP_Timer_backup.PWMUdb);
                SCP_Timer_WritePeriod(SCP_Timer_backup.PWMPeriod);
                
                #if(SCP_Timer_UseOneCompareMode)
                    SCP_Timer_WriteCompare(SCP_Timer_backup.PWMCompareValue);
                #else
                    SCP_Timer_WriteCompare1(SCP_Timer_backup.PWMCompareValue1);
                    SCP_Timer_WriteCompare2(SCP_Timer_backup.PWMCompareValue2);
                #endif
                
               #if(SCP_Timer_DeadBandMode == SCP_Timer__B_PWM__DBM_256_CLOCKS || SCP_Timer_DeadBandMode == SCP_Timer__B_PWM__DBM_2_4_CLOCKS)
                    SCP_Timer_WriteDeadTime(SCP_Timer_backup.PWMdeadBandValue);
                #endif
            
                #if ( SCP_Timer_KillModeMinTime)
                    SCP_Timer_WriteKillTime(SCP_Timer_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (SCP_Timer_PSOC3_ES3 || SCP_Timer_PSOC5_ES2)
                #if(!SCP_Timer_PWMModeIsCenterAligned)
                    SCP_Timer_WritePeriod(SCP_Timer_backup.PWMPeriod);
                #endif
                SCP_Timer_WriteCounter(SCP_Timer_backup.PWMUdb);
                #if (SCP_Timer_UseStatus)
                    SCP_Timer_STATUS_MASK = SCP_Timer_backup.InterruptMaskValue;
                #endif
                
                #if(SCP_Timer_DeadBandMode == SCP_Timer__B_PWM__DBM_256_CLOCKS || SCP_Timer_DeadBandMode == SCP_Timer__B_PWM__DBM_2_4_CLOCKS)
                    SCP_Timer_WriteDeadTime(SCP_Timer_backup.PWMdeadBandValue);
                #endif
                
                #if(SCP_Timer_KillModeMinTime)
                    SCP_Timer_WriteKillTime(SCP_Timer_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(SCP_Timer_UseControl)
                SCP_Timer_WriteControlRegister(SCP_Timer_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: SCP_Timer_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timer_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SCP_Timer_Sleep(void)
{
    #if(SCP_Timer_UseControl)
        if(SCP_Timer_CTRL_ENABLE == (SCP_Timer_CONTROL & SCP_Timer_CTRL_ENABLE))
        {
            /*Component is enabled */
            SCP_Timer_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            SCP_Timer_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    SCP_Timer_Stop();
    
    /* Save registers configuration */
    SCP_Timer_SaveConfig();
}


/*******************************************************************************
* Function Name: SCP_Timer_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  SCP_Timer_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void SCP_Timer_Wakeup(void) 
{
     /* Restore registers values */
    SCP_Timer_RestoreConfig();
    
    if(SCP_Timer_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        SCP_Timer_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
